@@ -5,7 +5,7 @@ Arithmetic is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2022 Free Software Foundation, Inc.
+Copyright (C) 2015-2023 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -255,15 +255,16 @@ static void
 ui_check_options_and_arguments(struct arithmeticparams *p)
 {
   gal_list_str_t *token, *hdu;
-  char *filename, *basename=NULL;
   size_t nummultiext=0, numhdus=0;
+  char *tofilename=NULL, *basename=NULL;
   struct gal_options_common_params *cp=&p->cp;
 
   /* First, make sure that any tokens are actually given. */
   if(p->tokens==NULL)
-    error(EXIT_FAILURE, 0, "no input tokens. Please specify a filename or "
-          "number (as operands) along with operator(s) as input. Please run "
-          "any of the following commands for more information.\n\n"
+    error(EXIT_FAILURE, 0, "no input tokens. Please specify a file name "
+          "or number (as operands) along with operator(s) as input. "
+          "Please run any of the following commands for more "
+          "information.\n\n"
           "    $ astarithmetic --help           # Short info.\n"
           "    $ info astarithmetic             # Full invocation "
           "documentation.\n");
@@ -292,21 +293,23 @@ ui_check_options_and_arguments(struct arithmeticparams *p)
       /* Strings given to the 'tofile' or 'tofilefree' operators are also
          considered as outputs and we should delete them before starting
          the parse. */
-      if( strncmp(OPERATOR_PREFIX_TOFILE, token->v,
-                  OPERATOR_PREFIX_LENGTH_TOFILE)==0
-          || strncmp(OPERATOR_PREFIX_TOFILEFREE, token->v,
-                  OPERATOR_PREFIX_LENGTH_TOFILEFREE)==0 )
-        {
-          filename=&token->v[ OPERATOR_PREFIX_LENGTH_TOFILE ];
-          gal_checkset_writable_remove(filename, cp->keep, cp->dontdelete);
-        }
+      tofilename = ( strncmp(OPERATOR_PREFIX_TOFILE, token->v,
+                             OPERATOR_PREFIX_LENGTH_TOFILE)==0
+                     ? &token->v[ OPERATOR_PREFIX_LENGTH_TOFILE ]
+                     : ( strncmp(OPERATOR_PREFIX_TOFILEFREE, token->v,
+                                 OPERATOR_PREFIX_LENGTH_TOFILEFREE)==0
+                         ? &token->v[ OPERATOR_PREFIX_LENGTH_TOFILEFREE ]
+                         : NULL ) );
+      if(tofilename)
+        gal_checkset_writable_remove(tofilename, basename, cp->keep,
+                                     cp->dontdelete);
 
       /* This may be a simple filename. */
       else
         {
           /* This token is a file, count how many mult-extension files we
-             have and use the first to set the output filename (if it has
-             not been set). */
+             have and use the first to set the output file's name (if it
+             has not been set). */
           if( gal_array_name_recognized(token->v)
               || gal_fits_file_recognized(token->v) )
             {
@@ -322,8 +325,7 @@ ui_check_options_and_arguments(struct arithmeticparams *p)
 
               /* If no output name is given, we need to extract the output
                  name from the inputs. */
-              if(cp->output==NULL && basename==NULL)
-                basename=token->v;
+              if(basename==NULL) basename=token->v;
             }
 
           /* This token is a number. Check if a negative dash was present
@@ -338,7 +340,8 @@ ui_check_options_and_arguments(struct arithmeticparams *p)
      'makenew' when the user doesn't set an output name explicity), use a
      default name. */
   if(cp->output)
-    gal_checkset_writable_remove(cp->output, cp->keep, cp->dontdelete);
+    gal_checkset_writable_remove(cp->output, basename, cp->keep,
+                                 cp->dontdelete);
   else
     {
       if(basename)
@@ -347,7 +350,7 @@ ui_check_options_and_arguments(struct arithmeticparams *p)
       else
         {
           gal_checkset_allocate_copy("arithmetic.fits", &cp->output);
-          gal_checkset_writable_remove(cp->output, cp->keep,
+          gal_checkset_writable_remove(cp->output, basename, cp->keep,
                                        cp->dontdelete);
         }
     }
@@ -385,12 +388,13 @@ ui_preparations(struct arithmeticparams *p)
   if(p->wcsfile && strcmp(p->wcsfile,"none"))
     {
       /* Read the number of dimensions and the size of each. */
-      dsize=gal_fits_img_info_dim(p->wcsfile, p->wcshdu, &ndim);
+      dsize=gal_fits_img_info_dim(p->wcsfile, p->wcshdu, &ndim,
+                                  "--wcshdu");
 
       /* Read the WCS. */
       p->refdata.wcs=gal_wcs_read(p->wcsfile, p->wcshdu,
                                   p->cp.wcslinearmatrix, 0, 0,
-                                  &p->refdata.nwcs);
+                                  &p->refdata.nwcs, "--wcshdu");
       if(p->refdata.wcs)
         {
           if(!p->cp.quiet)
