@@ -34,6 +34,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <gnuastro/txt.h>
 #include <gnuastro/fits.h>
 #include <gnuastro/jpeg.h>
+#include <gnuastro/tiff.h>
 #include <gnuastro/arithmetic.h>
 
 #include <gnuastro-internal/timing.h>
@@ -362,6 +363,13 @@ convertt(struct converttparams *p)
                     p->bordercolor, p->forcemin || p->forcemax, p->marks);
       break;
 
+    /* TIFF */
+    case OUT_FORMAT_TIFF:
+      if(p->colormap) color_map_prepare(p); else convertt_scale_to_uchar(p);
+      gal_tiff_write(p->chll, p->cp.output);
+      break;
+
+
     /* Not recognized. */
     default:
       error(EXIT_FAILURE, 0, "%s: a bug! Please contact us so we can find "
