@@ -753,9 +753,9 @@ ui_make_channels_ll(struct converttparams *p)
 
           /* Read in the array and its WCS information. */
           data=gal_fits_img_read(name->v, hdu, p->cp.minmapsize,
-                                 p->cp.quietmmap);
+                                 p->cp.quietmmap, "--hdu");
           data->wcs=gal_wcs_read(name->v, hdu, p->cp.wcslinearmatrix,
-                                 0, 0, &data->nwcs);
+                                 0, 0, &data->nwcs, "--hdu");
           data->ndim=gal_dimension_remove_extra(data->ndim, data->dsize,
                                                 data->wcs);
           gal_list_data_add(&p->chll, data);
@@ -1165,9 +1165,12 @@ ui_set_output(struct converttparams *p)
 
   /* TIFF */
   else if( gal_tiff_name_is_tiff(cp->output) )
-      error(EXIT_FAILURE, 0, "writing TIFF files is not yet supported, "
-            "please get in touch with us at %s so we implement it",
-            PACKAGE_BUGREPORT);
+    {
+      p->outformat=OUT_FORMAT_TIFF;
+       if( gal_tiff_suffix_is_tiff(cp->output) )
+          ui_add_dot_use_automatic_output(p);
+    }
+
 
   /* EPS */
   else if(gal_eps_name_is_eps(cp->output))
@@ -1300,7 +1303,7 @@ ui_marks_read_raw(struct converttparams *p, gal_data_t **coord1,
   table=gal_table_read(p->marksname, p->markshdu, NULL, cols,
                        p->cp.searchin, p->cp.ignorecase,
                        p->cp.numthreads, p->cp.minmapsize,
-                       p->cp.quietmmap, NULL);
+                       p->cp.quietmmap, NULL, "--markshdu");
 
   /* Make sure that we have only one column for each entry (it may happen
      that a table has two columns with the same name!). */
