@@ -6,7 +6,7 @@ Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
      Pedram Ashofteh-Ardakani <pedramardakani@pm.me>
-Copyright (C) 2016-2022 Free Software Foundation, Inc.
+Copyright (C) 2016-2023 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -308,7 +308,7 @@ ui_check_copykeys(struct fitsparams *p)
         {
           if(p->copykeysrange[0]==GAL_BLANK_LONG)
             {
-              p->copykeysname=gal_options_parse_csv_strings_raw(pt,
+              p->copykeysname=gal_options_parse_csv_strings_to_data(pt,
                                                                 NULL, 0);
               break;
             }
@@ -441,13 +441,13 @@ ui_read_check_mode_keyword(struct fitsparams *p)
 
       /* Give an ID to recognized coordinate systems. */
       if(p->wcscoordsys)
-        p->coordsysid=gal_wcs_coordsys_from_string(p->wcscoordsys);
+        p->coordsysid=gal_wcs_coordsys_name_to_id(p->wcscoordsys);
 
       /* Identify the requested distortion. Note that this also acts as a
          sanity check because it will crash with an error if the given
          string isn't recognized. */
       if(p->wcsdistortion)
-        p->distortionid=gal_wcs_distortion_from_string(p->wcsdistortion);
+        p->distortionid=gal_wcs_distortion_name_to_id(p->wcsdistortion);
 
       /* Make sure the value of '--keyvalue' is actually present. */
       if(p->keyvalue && p->keyvalue->v[0]=='\0')
@@ -514,7 +514,8 @@ ui_read_check_mode_extension(struct fitsparams *p)
       else
         {
           if(p->cp.output)
-            gal_checkset_writable_remove(p->cp.output, 1, p->cp.dontdelete);
+            gal_checkset_writable_remove(p->cp.output, p->input->v, 1,
+                                         p->cp.dontdelete);
           else
             p->cp.output=gal_checkset_automatic_output(&p->cp, p->input->v,
                                                        "_ext.fits");
