@@ -5,7 +5,7 @@ MakeCatalog is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2021, Free Software Foundation, Inc.
+Copyright (C) 2015-2023 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -35,6 +35,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <gnuastro/wcs.h>
 #include <gnuastro/data.h>
 #include <gnuastro/fits.h>
+#include <gnuastro/units.h>
 #include <gnuastro/threads.h>
 #include <gnuastro/pointer.h>
 #include <gnuastro/dimension.h>
@@ -88,6 +89,106 @@ mkcatalog_clump_starting_index(struct mkcatalog_passparams *pp)
 
 
 
+/* Vector allocation (short name is used since it is repeated a lot). */
+static void
+mkcatalog_vec_alloc(struct mkcatalog_passparams *pp, size_t onum,
+                    size_t vnum, uint8_t type)
+{
+  if( pp->p->oiflag[ onum ] )
+    gal_data_initialize(&pp->vector[vnum], 0, type, 1,
+                        &(pp->p->objects->dsize[0]), NULL, 1,
+                        pp->p->cp.minmapsize, pp->p->cp.quietmmap,
+                        NULL, NULL, NULL);
+}
+
+
+
+
+
+/* Allocate all the necessary space. */
+static void
+mkcatalog_single_object_init(struct mkcatalogparams *p,
+                             struct mkcatalog_passparams *pp)
+{
+  uint8_t *oif=p->oiflag;
+  size_t ndim=p->objects->ndim;
+  uint8_t i32=GAL_TYPE_INT32, f64=GAL_TYPE_FLOAT64; /* For short lines.*/
+
+  /* Initialize the mkcatalog_passparams elements. */
+  pp->p               = p;
+  pp->clumpstartindex = 0;
+  pp->rng             = p->rng ? gsl_rng_clone(p->rng) : NULL;
+  pp->oi              = gal_pointer_allocate(GAL_TYPE_FLOAT64,
+                                             OCOL_NUMCOLS, 0, __func__,
+                                             "pp->oi");
+
+  /* If we have second order measurements, allocate the array keeping the
+     temporary shift values for each object of this thread. Note that the
+     clumps catalog (if requested), will have the same measurements, so its
+     just enough to check the objects. */
+  pp->shift = ( (    oif[ OCOL_GXX ]
+                  || oif[ OCOL_GYY ]
+                  || oif[ OCOL_GXY ]
+                  || oif[ OCOL_VXX ]
+                  || oif[ OCOL_VYY ]
+                  || oif[ OCOL_VXY ] )
+                ? gal_pointer_allocate(GAL_TYPE_SIZE_T, ndim, 0, __func__,
+                                       "pp->shift")
+                : NULL );
+
+  /* If we have upper-limit mode, then allocate the container to keep the
+     values to calculate the standard deviation. */
+  if(p->upperlimit)
+    {
+      /* Allocate the space to keep the upper-limit values. */
+      pp->up_vals = gal_data_alloc(NULL, GAL_TYPE_FLOAT32, 1, &p->upnum,
+                                  NULL, 0, p->cp.minmapsize,
+                                  p->cp.quietmmap, NULL, NULL, NULL);
+
+      /* Set the blank checked flag to 1. By definition, this dataset won't
+         have any blank values. Also 'flag' is initialized to '0'. So we
+         just have to set the checked flag ('GAL_DATA_FLAG_BLANK_CH') to
+         one to inform later steps that there are no blank values. */
+      pp->up_vals->flag |= GAL_DATA_FLAG_BLANK_CH;
+    }
+  else
+    pp->up_vals=NULL;
+
+  /* If any vector measurements are necessary, do the necessary
+     allocations: first the general array, to keep all that are necessary,
+     then the individual ones. */
+  pp->vector = ( (    oif[ OCOL_NUMINSLICE         ]
+                   || oif[ OCOL_SUMINSLICE         ]
+                   || oif[ OCOL_NUMALLINSLICE      ]
+                   || oif[ OCOL_SUMVARINSLICE      ]
+                   || oif[ OCOL_SUMPROJINSLICE     ]
+                   || oif[ OCOL_NUMPROJINSLICE     ]
+                   || oif[ OCOL_SUMPROJVARINSLICE  ]
+                   || oif[ OCOL_NUMOTHERINSLICE    ]
+                   || oif[ OCOL_SUMOTHERINSLICE    ]
+                   || oif[ OCOL_SUMOTHERVARINSLICE ]
+                   || oif[ OCOL_NUMALLOTHERINSLICE ] )
+                 ? gal_data_array_calloc(VEC_NUM)
+                 : NULL );
+  mkcatalog_vec_alloc(pp, OCOL_NUMINSLICE,      VEC_NUMINSLICE,     i32);
+  mkcatalog_vec_alloc(pp, OCOL_NUMALLINSLICE,   VEC_NUMALLINSLICE,  i32);
+  mkcatalog_vec_alloc(pp, OCOL_NUMPROJINSLICE,  VEC_NUMPROJINSLICE, i32);
+  mkcatalog_vec_alloc(pp, OCOL_NUMOTHERINSLICE, VEC_NUMOTHERINSLICE,i32);
+  mkcatalog_vec_alloc(pp, OCOL_SUMINSLICE,      VEC_SUMINSLICE,     f64);
+  mkcatalog_vec_alloc(pp, OCOL_SUMVARINSLICE,   VEC_SUMVARINSLICE,  f64);
+  mkcatalog_vec_alloc(pp, OCOL_SUMPROJINSLICE,  VEC_SUMPROJINSLICE, f64);
+  mkcatalog_vec_alloc(pp, OCOL_SUMOTHERINSLICE, VEC_SUMOTHERINSLICE,f64);
+  mkcatalog_vec_alloc(pp, OCOL_SUMOTHERVARINSLICE, VEC_SUMOTHERVARINSLICE,
+                      f64);
+  mkcatalog_vec_alloc(pp, OCOL_NUMALLOTHERINSLICE, VEC_NUMALLOTHERINSLICE,
+                      i32);
+  mkcatalog_vec_alloc(pp, OCOL_SUMPROJVARINSLICE, VEC_SUMPROJVARINSLICE,
+                      f64);
+}
+
+
+
+
 
 /* Each thread will call this function once. It will go over all the
    objects that are assigned to it. */
@@ -96,51 +197,12 @@ mkcatalog_single_object(void *in_prm)
 {
   struct gal_threads_params *tprm=(struct gal_threads_params *)in_prm;
   struct mkcatalogparams *p=(struct mkcatalogparams *)(tprm->params);
-  size_t ndim=p->objects->ndim;
 
   size_t i;
-  uint8_t *oif=p->oiflag;
   struct mkcatalog_passparams pp;
 
-
-  /* Initialize the mkcatalog_passparams elements. */
-  pp.p               = p;
-  pp.clumpstartindex = 0;
-  pp.rng             = p->rng ? gsl_rng_clone(p->rng) : NULL;
-  pp.oi              = gal_pointer_allocate(GAL_TYPE_FLOAT64, OCOL_NUMCOLS,
-                                            0, __func__, "pp.oi");
-
-  /* If we have second order measurements, allocate the array keeping the
-     temporary shift values for each object of this thread. Note that the
-     clumps catalog (if requested), will have the same measurements, so its
-     just enough to check the objects. */
-  pp.shift = ( ( oif[    OCOL_GXX ]
-                 || oif[ OCOL_GYY ]
-                 || oif[ OCOL_GXY ]
-                 || oif[ OCOL_VXX ]
-                 || oif[ OCOL_VYY ]
-                 || oif[ OCOL_VXY ] )
-               ? gal_pointer_allocate(GAL_TYPE_SIZE_T, ndim, 0, __func__,
-                                       "pp.shift")
-               : NULL );
-
-  /* If we have upper-limit mode, then allocate the container to keep the
-     values to calculate the standard deviation. */
-  if(p->upperlimit)
-    {
-      /* Allocate the space to keep the upper-limit values. */
-      pp.up_vals = gal_data_alloc(NULL, GAL_TYPE_FLOAT32, 1, &p->upnum,
-                                  NULL, 0, p->cp.minmapsize, p->cp.quietmmap,
-                                  NULL, NULL, NULL);
-
-      /* Set the blank checked flag to 1. By definition, this dataset won't
-         have any blank values. Also 'flag' is initialized to '0'. So we
-         just have to set the checked flag ('GAL_DATA_FLAG_BLANK_CH') to
-         one to inform later steps that there are no blank values. */
-      pp.up_vals->flag |= GAL_DATA_FLAG_BLANK_CH;
-    }
-  else
-    pp.up_vals=NULL;
+  /* Initialize and allocate all the necessary values. */
+  mkcatalog_single_object_init(p, &pp);
 
   /* Fill the desired columns for all the objects given to this thread. */
   for(i=0; tprm->indexs[i]!=GAL_BLANK_SIZE_T; ++i)
@@ -152,7 +214,6 @@ mkcatalog_single_object(void *in_prm)
                       ? p->outlabs[ tprm->indexs[i] ]
                       : tprm->indexs[i] + 1 );
       pp.tile     = &p->tiles[   tprm->indexs[i] ];
-      pp.spectrum = &p->spectra[ tprm->indexs[i] ];
 
       /* Initialize the parameters for this object/tile. */
       parse_initialize(&pp);
@@ -180,16 +241,16 @@ mkcatalog_single_object(void *in_prm)
 
       /* If an order-based calculation is requested, another pass is
          necessary. */
-      if( p->oiflag[ OCOL_MEDIAN ]
-          || p->oiflag[ OCOL_MAXIMUM ]
-          || p->oiflag[ OCOL_HALFMAXSUM ]
-          || p->oiflag[ OCOL_HALFMAXNUM ]
-          || p->oiflag[ OCOL_HALFSUMNUM ]
-          || p->oiflag[ OCOL_SIGCLIPNUM ]
-          || p->oiflag[ OCOL_SIGCLIPSTD ]
-          || p->oiflag[ OCOL_SIGCLIPMEAN ]
-          || p->oiflag[ OCOL_FRACMAX1NUM ]
-          || p->oiflag[ OCOL_FRACMAX2NUM ]
+      if(    p->oiflag[ OCOL_MEDIAN        ]
+          || p->oiflag[ OCOL_MAXIMUM       ]
+          || p->oiflag[ OCOL_HALFMAXSUM    ]
+          || p->oiflag[ OCOL_HALFMAXNUM    ]
+          || p->oiflag[ OCOL_HALFSUMNUM    ]
+          || p->oiflag[ OCOL_SIGCLIPNUM    ]
+          || p->oiflag[ OCOL_SIGCLIPSTD    ]
+          || p->oiflag[ OCOL_SIGCLIPMEAN   ]
+          || p->oiflag[ OCOL_FRACMAX1NUM   ]
+          || p->oiflag[ OCOL_FRACMAX2NUM   ]
           || p->oiflag[ OCOL_SIGCLIPMEDIAN ])
         parse_order_based(&pp);
 
@@ -208,6 +269,7 @@ mkcatalog_single_object(void *in_prm)
   free(pp.shift);
   gal_data_free(pp.up_vals);
   if(pp.rng) gsl_rng_free(pp.rng);
+  gal_data_array_free(pp.vector, VEC_NUM, 1);
 
   /* Wait until all the threads finish and return. */
   if(tprm->b) pthread_barrier_wait(tprm->b);
@@ -337,86 +399,105 @@ mkcatalog_wcs_conversion(struct mkcatalogparams *p)
 
 
 void
-mkcatalog_write_inputs_in_comments(struct mkcatalogparams *p,
-                                   gal_list_str_t **comments, int withsky,
-                                   int withstd)
+mkcatalog_outputs_keys_numeric(gal_fits_list_key_t **keylist, void *number,
+                               uint8_t type, char *nameliteral,
+                               char *commentliteral, char *unitliteral)
 {
-  char *tmp, *str;
+  void *value;
+  value=gal_pointer_allocate(type, 1, 0, __func__, "value");
+  memcpy(value, number, gal_type_sizeof(type));
+  gal_fits_key_list_add_end(keylist, type, nameliteral, 0,
+                            value, 1, commentliteral, 0,
+                            unitliteral, 0);
+}
 
-  /* Basic classifiers for plain text outputs. */
-  if(p->cp.tableformat==GAL_TABLE_FORMAT_TXT)
-    {
-      if( asprintf(&str, "--------- Input files ---------")<0 )
-        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-      gal_list_str_add(comments, str, 0);
-    }
+
+
+
+
+void
+mkcatalog_outputs_keys_infiles(struct mkcatalogparams *p,
+                               gal_fits_list_key_t **keylist)
+{
+  int quiet=p->cp.quiet;
+  char *stdname, *stdhdu, *stdvalcom;
+
+  gal_fits_key_list_title_add_end(keylist,
+                                  "Input files and/or configuration", 0);
 
   /* Object labels. */
-  if( asprintf(&str, "Objects: %s (hdu: %s).", p->objectsfile, p->cp.hdu)<0 )
-    error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-  gal_list_str_add(comments, str, 0);
+  gal_fits_key_write_filename("INLAB", p->objectsfile, keylist, 0,
+                              quiet);
+  gal_fits_key_write_filename("INLABHDU", p->cp.hdu, keylist, 0,
+                              quiet);
 
   /* Clump labels. */
   if(p->clumps)
     {
-      if(asprintf(&str, "Clumps:  %s (hdu: %s).", p->usedclumpsfile,
-                  p->clumpshdu)<0)
-        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-      gal_list_str_add(comments, str, 0);
+      gal_fits_key_write_filename("INCLU", p->usedclumpsfile, keylist, 0,
+                                  quiet);
+      gal_fits_key_write_filename("INCLUHDU", p->clumpshdu, keylist, 0,
+                                  quiet);
     }
 
-  /* Values dataset. */
+  /* Values image. */
   if(p->values)
     {
-      if( asprintf(&str, "Values:  %s (hdu: %s).", p->usedvaluesfile,
-                   p->valueshdu)<0 )
-        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-      gal_list_str_add(comments, str, 0);
+      gal_fits_key_write_filename("INVAL", p->usedvaluesfile, keylist, 0,
+                                  quiet);
+      gal_fits_key_write_filename("INVALHDU", p->valueshdu, keylist, 0,
+                                  quiet);
     }
 
-  /* Sky dataset. */
-  if(withsky && p->sky)
+  /* Sky image/value. */
+  if(p->sky)
     {
       if(p->sky->size==1)
-        {
-          if( asprintf(&str, "Sky:     %g.", *((float *)(p->sky->array)) )<0 )
-            error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-        }
+        mkcatalog_outputs_keys_numeric(keylist, p->sky->array,
+                                       p->sky->type, "INSKYVAL",
+                                       "Value of Sky used (a single "
+                                       "number).", NULL);
       else
         {
-          if( asprintf(&str, "Sky:     %s (hdu: %s).", p->usedskyfile,
-                       p->skyhdu)<0 )
-            error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
+          gal_fits_key_write_filename("INSKY", p->usedskyfile, keylist, 0,
+                                      quiet);
+          gal_fits_key_write_filename("INSKYHDU", p->skyhdu, keylist, 0,
+                                      quiet);
         }
-      gal_list_str_add(comments, str, 0);
     }
 
-  /* Sky standard deviation dataset. */
-  tmp = p->variance ? "VAR" : "STD";
-  if(withstd && p->std)
+  /* Standard deviation (or variance) image. */
+  if(p->variance)
+    {
+      stdname="INVAR"; stdhdu="INVARHDU";
+      stdvalcom="Value of Sky variance (a single number).";
+    }
+  else
+    {
+      stdname="INSTD"; stdhdu="INSTDHDU";
+      stdvalcom="Value of Sky STD (a single number).";
+    }
+  if(p->std)
     {
       if(p->std->size==1)
-        {
-          if( asprintf(&str, "Sky %s: %g.", tmp,
-                       *((float *)(p->std->array)) )<0 )
-            error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-        }
+        mkcatalog_outputs_keys_numeric(keylist, p->std->array, p->std->type,
+                                       stdname, stdvalcom, NULL);
       else
         {
-          if( asprintf(&str, "Sky %s: %s (hdu: %s).", tmp, p->usedstdfile,
-                       p->stdhdu)<0 )
-            error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
+          gal_fits_key_write_filename(stdname, p->usedstdfile, keylist, 0,
+                                      quiet);
+          gal_fits_key_write_filename(stdhdu, p->stdhdu, keylist, 0,
+                                      quiet);
         }
-      gal_list_str_add(comments, str, 0);
     }
 
   /* Upper limit mask. */
   if(p->upmaskfile)
     {
-      if( asprintf(&str, "Upperlimit mask: %s (hdu: %s).", p->upmaskfile,
-                   p->upmaskhdu)<0 )
-        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-      gal_list_str_add(comments, str, 0);
+      gal_fits_key_write_filename("INUPM", p->upmaskfile, keylist, 0,
+                                  quiet);
+      gal_fits_key_write_filename("INUPMHDU", p->upmaskhdu, keylist, 0,
+                                  quiet);
     }
 }
 
@@ -424,166 +505,150 @@ mkcatalog_write_inputs_in_comments(struct mkcatalogparams *p,
 
 
 
-/* Write the similar information. */
-static gal_list_str_t *
-mkcatalog_outputs_same_start(struct mkcatalogparams *p, int o0c1,
-                             char *ObjClump)
+/* Write the output keywords. */
+static gal_fits_list_key_t *
+mkcatalog_outputs_keys(struct mkcatalogparams *p, int o0c1)
 {
-  char *str, *tstr;
-  double pixarea=NAN;
-  gal_list_str_t *comments=NULL;
+  float pixarea=NAN, fvalue;
+  gal_fits_list_key_t *keylist=NULL;
 
-  if( asprintf(&str, "%s catalog of %s", o0c1 ? "Object" : "Clump",
-               PROGRAM_STRING)<0 )
-    error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-  gal_list_str_add(&comments, str, 0);
+  /* First, add the file names. */
+  mkcatalog_outputs_keys_infiles(p, &keylist);
 
-  /* If in a Git controlled directory and output isn't a FITS file (in
-     FITS, this will be automatically included). */
+  /* Type of catalog. */
+  gal_fits_key_list_add_end(&keylist, GAL_TYPE_STRING, "CATTYPE", 0,
+                            o0c1 ? "clumps" : "objects", 0,
+                            "Type of catalog ('object' or 'clump').", 0,
+                            NULL, 0);
+
+  /* Add project commit information when in a Git-controlled directory and
+     the output isn't a FITS file (in FITS, this will be automatically
+     included). */
   if(p->cp.tableformat==GAL_TABLE_FORMAT_TXT && gal_git_describe())
-    {
-      if(asprintf(&str, "Working directory commit %s", gal_git_describe())<0)
-        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-      gal_list_str_add(&comments, str, 0);
-    }
-
-  /* Write the date. However, 'ctime' is going to put a new-line character
-     in the end of its string, so we are going to remove it manually. */
-  if( asprintf(&str, "%s started on %s", PROGRAM_NAME, ctime(&p->rawtime))<0 )
-    error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-  str[strlen(str)-1]='\0';
-  gal_list_str_add(&comments, str, 0);
-
-
-  /* Write the basic information. */
-  mkcatalog_write_inputs_in_comments(p, &comments, 1, 1);
-
-
-  /* Write other supplementary information. */
-  if(p->cp.tableformat==GAL_TABLE_FORMAT_TXT)
-    {
-      if( asprintf(&str, "--------- Supplementary information ---------")<0 )
-        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-      gal_list_str_add(&comments, str, 0);
-    }
+    gal_fits_key_list_add_end(&keylist, GAL_TYPE_STRING, "COMMIT", 0,
+                              gal_git_describe(), 1,
+                              "Git commit in running directory.", 0,
+                              NULL, 0);
 
   /* Pixel area. */
   if(p->objects->wcs)
     {
       pixarea=gal_wcs_pixel_area_arcsec2(p->objects->wcs);
       if( isnan(pixarea)==0 )
-        {
-          if( asprintf(&str, "Pixel area (arcsec^2): %g", pixarea)<0 )
-            error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-          gal_list_str_add(&comments, str, 0);
-        }
+        mkcatalog_outputs_keys_numeric(&keylist, &pixarea,
+                                       GAL_TYPE_FLOAT32, "PIXAREA",
+                                       "Pixel area of input image.",
+                                       "arcsec^2");
     }
 
-  /* Zeropoint magnitude */
-  if(p->hasmag)
-    {
-      if( asprintf(&str, "Zeropoint magnitude: %.4f", p->zeropoint)<0 )
-        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-      gal_list_str_add(&comments, str, 0);
-    }
+  /* Zeropoint magnitude. */
+  if( !isnan(p->zeropoint) )
+    mkcatalog_outputs_keys_numeric(&keylist, &p->zeropoint,
+                                   GAL_TYPE_FLOAT32, "ZEROPNT",
+                                   "Zeropoint used for magnitude.",
+                                   "mag");
 
-  /* Print surface brightness limits. */
+  /* Add the title for the keywords. */
+  gal_fits_key_list_title_add_end(&keylist, "Surface brightness limit "
+                                  "(SBL)", 0);
+
+  /* Print surface brightness limit. */
   if( !isnan(p->medstd) && !isnan(p->sfmagnsigma) )
     {
+      /* Used noise value (per pixel) and multiple of sigma. */
+      mkcatalog_outputs_keys_numeric(&keylist, &p->medstd,
+                                     GAL_TYPE_FLOAT32, "SBLSTD",
+                                     "Pixel STD for surface brightness "
+                                     "limit.", NULL);
+      mkcatalog_outputs_keys_numeric(&keylist, &p->sfmagnsigma,
+                                     GAL_TYPE_FLOAT32, "SBLNSIG",
+                                     "Sigma multiple for surface "
+                                     "brightness limit.", NULL);
+
       /* Only print magnitudes if a zeropoint is given. */
       if( !isnan(p->zeropoint) )
         {
-          /* Per pixel. */
-          if( asprintf(&str, "%g sigma surface brightness (magnitude/pixel): "
-                       "%.3f", p->sfmagnsigma, ( -2.5f
-                                                 *log10( p->sfmagnsigma
-                                                         * p->medstd )
-                                                 + p->zeropoint ) )<0 )
-            error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-          gal_list_str_add(&comments, str, 0);
+          /* Per pixel, Surface brightness limit magnitude. */
+          fvalue=gal_units_counts_to_mag(p->sfmagnsigma * p->medstd,
+                                         p->zeropoint);
+          mkcatalog_outputs_keys_numeric(&keylist, &fvalue,
+                                         GAL_TYPE_FLOAT32, "SBLMAGPX",
+                                         "Surface brightness limit per "
+                                         "pixel.", "mag/pix");
 
-          /* Requested projected area: if a pixel area could be measured (a
-             WCS was given), then also estimate the surface brightness over
-             one arcsecond^2. From the pixel area, we know how many pixels
-             are necessary to fill the requested projected area (in
-             arcsecond^2). We also know that as the number of samples
-             (pixels) increases (to N), the noise increases by sqrt(N), see
-             the full discussion in the book. */
-          if(!isnan(pixarea) && !isnan(p->sfmagarea))
+          /* Only print the SBL in fixed area if a WCS is present and a
+             pixel area could be deduced. */
+          if( !isnan(pixarea) )
             {
-              /* Prepare the comment/information. */
-              if(p->sfmagarea==1.0f)
-                tstr=NULL;
-              else
-                if( asprintf(&tstr, "%g-", p->sfmagarea)<0 )
-                  error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-              if( asprintf(&str, "%g sigma surface brightness "
-                           "(magnitude/%sarcsec^2): %.3f", p->sfmagnsigma,
-                           tstr ? tstr : "",
-                           ( -2.5f * log10( p->sfmagnsigma
-                                            * p->medstd
-                                            * sqrt( p->sfmagarea / pixarea) )
-                             + p->zeropoint ) )<0 )
-                error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
+              /* Area used for measuring SBL. */
+              mkcatalog_outputs_keys_numeric(&keylist, &p->sfmagarea,
+                                             GAL_TYPE_FLOAT32, "SBLAREA",
+                                             "Area for surface brightness "
+                                             "limit.", "arcsec^2");
 
-              /* Add the final string/line to the catalog comments. */
-              gal_list_str_add(&comments, str, 0);
-
-              /* Clean up (if necessary). */
-              if (tstr)
-                {
-                  free(tstr);
-                  tstr=NULL;
-                }
+              /* Per area, Surface brightness limit magnitude. */
+              fvalue=gal_units_counts_to_mag(p->sfmagnsigma
+                                             * p->medstd
+                                             / sqrt( p->sfmagarea
+                                                     * pixarea),
+                                             p->zeropoint);
+              mkcatalog_outputs_keys_numeric(&keylist, &fvalue,
+                                             GAL_TYPE_FLOAT32, "SBLMAG",
+                                             "Surf. bright. limit in "
+                                             "SBLAREA.",
+                                             "mag/arcsec^2");
             }
+          else
+            gal_fits_key_list_fullcomment_add_end(&keylist, "Can't "
+                   "write surface brightness limiting magnitude (SBLM) "
+                   "values in fixed area ('SBLAREA' and 'SBLMAG' "
+                   "keywords) because input doesn't have a world "
+                   "coordinate system (WCS), or the first two "
+                   "coordinates of the WCS weren't angular positions "
+                   "in units of degrees.", 0);
         }
-
-      /* Notice: */
-      if( asprintf(&str, "Pixel STD for surface brightness calculation%s: %f",
-                   (!isnan(pixarea) && !isnan(p->sfmagarea))?"s":"",
-                   p->medstd)<0 )
-        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-      gal_list_str_add(&comments, str, 0);
+      else
+        gal_fits_key_list_fullcomment_add_end(&keylist, "Can't write "
+               "surface brightness limiting magnitude values (e.g., "
+               "'SBLMAG' or 'SBLMAGPX' keywords) because no "
+               "'--zeropoint' has been given.", 0);
     }
   else
     {
-      gal_checkset_allocate_copy("No surface brightness calcuations "
-                                 "because no STD image used.", &str);
-      gal_list_str_add(&comments, str, 0);
-      gal_checkset_allocate_copy("Ask for column that uses the STD image, "
-                                 "or '--forcereadstd'.", &str);
-      gal_list_str_add(&comments, str, 0);
+      gal_fits_key_list_fullcomment_add_end(&keylist, "No surface "
+             "brightness calcuations (e.g., 'SBLMAG' or 'SBLMAGPX' "
+             "keywords) because STD image didn't have the 'MEDSTD' "
+             "keyword. There are two solutions: 1) Call with "
+             "'--forcereadstd'. 2) Measure the median noise level "
+             "manually (possibly with Gnuastro's Arithmetic program) "
+             "and put the value in the 'MEDSTD' keyword of the STD "
+             "image.", 0);
+      gal_fits_key_list_fullcomment_add_end(&keylist, "", 0);
     }
 
   /* The count-per-second correction. */
   if(p->cpscorr>1.0f)
-    {
-      if( asprintf(&str, "Counts-per-second correction: %.3f", p->cpscorr)<0 )
-        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-      gal_list_str_add(&comments, str, 0);
-    }
+    mkcatalog_outputs_keys_numeric(&keylist, &p->cpscorr,
+                                   GAL_TYPE_FLOAT32, "CPSCORR",
+                                   "Counts-per-second correction.",
+                                   NULL);
 
   /* Print upper-limit parameters. */
   if(p->upperlimit)
-    upperlimit_write_comments(p, &comments, 1);
+    upperlimit_write_keys(p, &keylist, 1);
 
-  /* Start column metadata. */
+  /* In plain-text outputs, put a title for column metadata. */
   if(p->cp.tableformat==GAL_TABLE_FORMAT_TXT)
-    {
-      if( asprintf(&str, "--------- Table columns ---------")<0 )
-        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-      gal_list_str_add(&comments, str, 0);
-    }
+    gal_fits_key_list_title_add_end(&keylist, "Column metadata", 0);
 
-  /* Return the comments. */
-  return comments;
+  /* Return the list of keywords. */
+  return keylist;
 }
 
 
 
 
 
-
 /* Since all the measurements were done in parallel (and we didn't know the
    number of clumps per object a-priori), the clumps informtion is just
    written in as they are measured. Here, we'll sort the clump columns by
@@ -644,21 +709,20 @@ sort_clumps_by_objid(struct mkcatalogparams *p)
 static void
 mkcatalog_write_outputs(struct mkcatalogparams *p)
 {
-  size_t i, scounter;
-  char str[200], *fname;
-  gal_list_str_t *comments;
+  gal_fits_list_key_t *keylist;
+  gal_list_str_t *comments=NULL;
   int outisfits=gal_fits_name_is_fits(p->objectsout);
 
   /* If a catalog is to be generated. */
   if(p->objectcols)
     {
       /* OBJECT catalog */
-      comments=mkcatalog_outputs_same_start(p, 0, "Detection");
+      keylist=mkcatalog_outputs_keys(p, 0);
 
       /* Reverse the comments list (so it is printed in the same order
          here), write the objects catalog and free the comments. */
       gal_list_str_reverse(&comments);
-      gal_table_write(p->objectcols, NULL, comments, p->cp.tableformat,
+      gal_table_write(p->objectcols, &keylist, NULL, p->cp.tableformat,
                       p->objectsout, "OBJECTS", 0);
       gal_list_str_free(comments, 1);
 
@@ -667,7 +731,7 @@ mkcatalog_write_outputs(struct mkcatalogparams *p)
       if(p->clumps)
         {
           /* Make the comments. */
-          comments=mkcatalog_outputs_same_start(p, 1, "Clumps");
+          keylist=mkcatalog_outputs_keys(p, 1);
 
           /* Write objects catalog
              ---------------------
@@ -681,86 +745,28 @@ mkcatalog_write_outputs(struct mkcatalogparams *p)
         }
     }
 
-  /* Spectra. */
-  if(p->spectra)
-    {
-      /* Inform the user (Writing many FITS extensions can take
-         long). */
-      if(p->objectcols && outisfits)
-        printf("  - Catalog(s) complete, writing spectra.\n");
-
-      /* Start counting and writing the files. Note that due to some
-         conditions (for example in debugging), a 'p->spectra[i]' may not
-         actually contain any data. So we'll also count the number of
-         spectra that are written. */
-      scounter=0;
-      for(i=0;i<p->numobjects;++i)
-        if(p->spectra[i].ndim>0)
-          {
-            /* Increment the written spectra-counter. */
-            ++scounter;
-
-            /* Write the spectra based on the requested format. */
-            if(outisfits)
-              {
-                /* Write the table. */
-                sprintf(str, "SPECTRUM_%zu", i+1);
-                gal_table_write(&p->spectra[i], NULL, NULL,
-                                GAL_TABLE_FORMAT_BFITS,
-                                p->objectsout, str, 0);
-              }
-            else
-              {
-                sprintf(str, "-spec-%zu.txt", i+1);
-                fname=gal_checkset_automatic_output(&p->cp, p->objectsout,
-                                                    str);
-                gal_table_write(&p->spectra[i], NULL, NULL, GAL_TABLE_FORMAT_TXT,
-                                fname, NULL, 0);
-                free(fname);
-              }
-          }
-    }
-
   /* Configuration information. */
   if(outisfits)
     {
-      gal_fits_key_write_filename("input", p->objectsfile, &p->cp.okeys, 1);
+      gal_fits_key_write_filename("input", p->objectsfile, &p->cp.okeys,
+                                  1, p->cp.quiet);
       gal_fits_key_write_config(&p->cp.okeys, "MakeCatalog configuration",
-                                "MKCATALOG-CONFIG", p->objectsout, "0");
+                                "MKCATALOG-CONFIG", p->objectsout, "0",
+                                "NONE");
     }
 
 
   /* Inform the user */
-  if(!p->cp.quiet)
+  if(!p->cp.quiet && p->objectcols)
     {
-      if(p->objectcols)
+      if(p->clumpsout && strcmp(p->clumpsout,p->objectsout))
         {
-          if(p->clumpsout && strcmp(p->clumpsout,p->objectsout))
-            {
-              printf("  - Output objects catalog: %s\n", p->objectsout);
-              if(p->clumps)
-                printf("  - Output clumps catalog: %s\n", p->clumpsout);
-            }
-          else
-            printf("  - Catalog written to %s\n", p->objectsout);
-
-        }
-
-      if(p->spectra)
-        {
-          if(outisfits)
-            {
-              if(p->objectcols)
-                printf("  - Spectra in %zu extensions named 'SPECTRUM_NN'.\n",
-                       p->numobjects);
-              else
-                printf("  - Output: %s (Spectra in %zu extensions named "
-                       "'SPECTRUM_NN').\n)", p->objectsout, p->numobjects);
-            }
-          else
-            printf("  - Spectra in %zu files with '-spec-NN.txt' suffix.\n",
-                   p->numobjects);
+          printf("  - Output objects catalog: %s\n", p->objectsout);
+          if(p->clumps)
+            printf("  - Output clumps catalog: %s\n", p->clumpsout);
         }
+      else
+        printf("  - Catalog written to %s\n", p->objectsout);
     }
 }
 
