@@ -90,7 +90,7 @@ struct argp_option program_options[] =
       0,
       "File for 'custom-prof' profile.",
       GAL_OPTIONS_GROUP_INPUT,
-      &p->customprofname,
+      &p->customtablename,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
       GAL_OPTIONS_NOT_MANDATORY,
@@ -103,7 +103,7 @@ struct argp_option program_options[] =
       0,
       "HDU of table given to '--customtable'.",
       GAL_OPTIONS_GROUP_INPUT,
-      &p->customprofhdu,
+      &p->customtablehdu,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
       GAL_OPTIONS_NOT_MANDATORY,
