@@ -5,7 +5,7 @@ MakeProfiles is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2022 Free Software Foundation, Inc.
+Copyright (C) 2015-2023 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -144,7 +144,7 @@ saveindividual(struct mkonthread *mkp)
     {
       if( asprintf(&filename, "%s%zu_%s", outdir, ibq->id, p->basename)<0 )
         error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
-      gal_checkset_writable_remove(filename, 0, p->cp.dontdelete);
+      gal_checkset_writable_remove(filename, NULL, 0, p->cp.dontdelete);
     }
 
 
@@ -258,16 +258,16 @@ saveindividual(struct mkonthread *mkp)
       gal_fits_key_list_add(&keys, GAL_TYPE_UINT8, "MFORFLATPIX", 0,
                             &p->mforflatpix, 0, "Magnitude is flat pixel "
                             "value", 0, NULL, 0);
-  gal_fits_key_list_add(&keys, GAL_TYPE_UINT8, "MCOLISBRIGHTNESS", 0,
-                        &p->mcolisbrightness, 0, "Catalog's magnitude is "
-                        "actually brightness", 0, NULL, 0);
+  gal_fits_key_list_add(&keys, GAL_TYPE_UINT8, "MCOLISSUM", 0,
+                        &p->mcolissum, 0, "Catalog's magnitude is "
+                        "total sum", 0, NULL, 0);
   gal_fits_key_list_add(&keys, GAL_TYPE_UINT8, "MAGATPEAK", 0,
                         &p->magatpeak, 0, "Magnitude is for peak pixel, "
                         "not full profile", 0, NULL, 0);
 
   gal_fits_key_list_reverse(&keys);
-  gal_fits_key_write_config(&keys, "Profile configuration", "PROFILE-CONFIG",
-                            filename, "0");
+  gal_fits_key_write_config(&keys, "Profile configuration",
+                            "PROFILE-CONFIG", filename, "0", "NONE");
 
 
   /* Report if in verbose mode. */
@@ -370,11 +370,12 @@ mkprof_build_single(struct mkonthread *mkp, long *fpixel_i, long *lpixel_i,
           /* If a crop is needed, set the starting pointer. */
           ind=gal_dimension_coord_to_index(ndim, ibq->image->dsize,
                                            start_indiv);
-          ptr=gal_pointer_increment(ibq->image->array, ind, ibq->image->type);
+          ptr=gal_pointer_increment(ibq->image->array, ind,
+                                    ibq->image->type);
         }
       else ptr=ibq->image->array;
-      ibq->overlap_i=gal_data_alloc(ptr, ibq->image->type, ndim, dsize, NULL,
-                                    0, -1, 1, NULL, NULL, NULL);
+      ibq->overlap_i=gal_data_alloc(ptr, ibq->image->type, ndim, dsize,
+                                    NULL, 0, -1, 1, NULL, NULL, NULL);
       ibq->overlap_i->block=ibq->image;
 
 
@@ -484,6 +485,7 @@ mkprof_build(void *inparam)
 {
   struct mkonthread *mkp=(struct mkonthread *)inparam;
   struct mkprofparams *p=mkp->p;
+
   size_t i, id, ndim=p->ndim;
   struct builtqueue *ibq, *fbq=NULL;
   double center[3], semiaxes[3], euler_deg[3];
@@ -504,14 +506,24 @@ mkprof_build(void *inparam)
       id=ibq->id=mkp->indexs[i];
       if(fbq==NULL) fbq=ibq;
 
-
       /* Write the necessary parameters for this profile into 'mkp'.*/
       oneprofile_set_prof_params(mkp);
 
-
       /* Find the bounding box size (NOT oversampled). */
       if( p->f[id] == PROFILE_POINT )
-        mkp->width[0]=mkp->width[1]=1;
+        {
+          mkp->width[0]=mkp->width[1]=1;
+          if(ndim==3) mkp->width[2]=1;
+        }
+      else if( p->f[id] == PROFILE_CUSTOM_IMG )
+        {
+          mkp->width[0]=mkp->customimg->dsize[1]; /* 'width' is in */
+          mkp->width[1]=mkp->customimg->dsize[0]; /* FITS order not C. */
+          if(ndim==3)
+            error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at "
+                  "'%s' to fix the problem. Custom images are not yet "
+                  "supported for 3D inputs", __func__, PACKAGE_BUGREPORT);
+        }
       else
         switch(ndim)
           {
@@ -711,7 +723,8 @@ mkprof_write(struct mkprofparams *p)
       gal_fits_key_write_filename("input", p->catname, &p->cp.okeys, 1,
                                   p->cp.quiet);
       gal_fits_key_write_config(&p->cp.okeys, "MakeProfiles configuration",
-                                "MKPROF-CONFIG", p->mergedimgname, "0");
+                                "MKPROF-CONFIG", p->mergedimgname, "0",
+                                "NONE");
 
       /* In verbose mode, print the information. */
       if(!p->cp.quiet)
@@ -765,7 +778,7 @@ mkprof(struct mkprofparams *p)
      thread. Note that we only want nt-1 threads to do the
      building. */
   errno=0;
-  mkp=malloc(nt*sizeof *mkp);
+  mkp=calloc(nt, sizeof *mkp);
   if(mkp==NULL)
     error(EXIT_FAILURE, errno, "%s: allocating %zu bytes for 'mkp'",
           __func__, (nt-1)*sizeof *mkp);
@@ -784,7 +797,8 @@ mkprof(struct mkprofparams *p)
      ignore it. */
   if(p->out)
     {
-      onaxes=gal_pointer_allocate(GAL_TYPE_LONG, ndim, 0, __func__, "onaxes");
+      onaxes=gal_pointer_allocate(GAL_TYPE_LONG, ndim, 0, __func__,
+                                  "onaxes");
       for(fi=0; fi < ndim; ++fi)
         {
           i=ndim-fi-1;
@@ -814,10 +828,11 @@ mkprof(struct mkprofparams *p)
 
       /* Initialize the condition variable and mutex. */
       err=pthread_mutex_init(&p->qlock, NULL);
-      if(err) error(EXIT_FAILURE, 0, "%s: mutex not initialized", __func__);
-      err=pthread_cond_init(&p->qready, NULL);
-      if(err) error(EXIT_FAILURE, 0, "%s: condition variable not initialized",
+      if(err) error(EXIT_FAILURE, 0, "%s: mutex not initialized",
                     __func__);
+      err=pthread_cond_init(&p->qready, NULL);
+      if(err) error(EXIT_FAILURE, 0, "%s: condition variable not "
+                    "initialized", __func__);
 
       /* Spin off the threads: */
       for(i=0;i<nt;++i)
@@ -866,7 +881,7 @@ mkprof(struct mkprofparams *p)
       if( asprintf(&tmp, "Zeropoint: %g", p->zeropoint)<0 )
         error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
       gal_list_str_add(&comments, tmp, 0);
-      gal_checkset_writable_remove(LOGFILENAME, 0, p->cp.dontdelete);
+      gal_checkset_writable_remove(LOGFILENAME, NULL, 0, p->cp.dontdelete);
       gal_table_write_log(p->log, PROGRAM_STRING, &p->rawtime, comments,
                           LOGFILENAME, p->cp.quiet);
       gal_list_str_free(comments, 1);
