@@ -5,7 +5,7 @@ NoiseChisel is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015-2021, Free Software Foundation, Inc.
+Copyright (C) 2015-2023 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -68,7 +68,8 @@ noisechisel_convolve(struct noisechiselparams *p)
           /* Make the convolved image. */
           if(!p->cp.quiet) gettimeofday(&t1, NULL);
           p->conv = gal_convolve_spatial(tl->tiles, p->kernel,
-                                         p->cp.numthreads, 1, tl->workoverch);
+                                         p->cp.numthreads, 1,
+                                         tl->workoverch, 0);
 
           /* Report and write check images if necessary. */
           if(!p->cp.quiet)
@@ -106,7 +107,8 @@ noisechisel_convolve(struct noisechiselparams *p)
     {
       if(!p->cp.quiet) gettimeofday(&t1, NULL);
       p->wconv=gal_convolve_spatial(tl->tiles, p->widekernel,
-                                    p->cp.numthreads, 1, tl->workoverch);
+                                    p->cp.numthreads, 1,
+                                    tl->workoverch, 0);
       gal_checkset_allocate_copy("CONVOLVED-WIDER", &p->wconv->name);
 
       if(!p->cp.quiet)
@@ -206,9 +208,11 @@ noisechisel_output(struct noisechiselparams *p)
 
 
   /* Write the configuration keywords. */
-  gal_fits_key_write_filename("input", p->inputname, &p->cp.okeys, 1);
+  gal_fits_key_write_filename("input", p->inputname, &p->cp.okeys, 1,
+                              p->cp.quiet);
   gal_fits_key_write_config(&p->cp.okeys, "NoiseChisel configuration",
-                            "NOISECHISEL-CONFIG", p->cp.output, "0");
+                            "NOISECHISEL-CONFIG", p->cp.output, "0",
+                            "NONE");
 
 
   /* Let the user know that the output is written. */
