@@ -5,7 +5,7 @@ Query is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2020-2022 Free Software Foundation, Inc.
+Copyright (C) 2020-2023 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -78,7 +78,7 @@ query_output_meta_database(struct queryparams *p)
   /* Get the downloaded metadata column information so we can ask for the
      proper columns. */
   allcols=gal_table_info(p->downloadname, "1", NULL, &numcols,
-                         &numrows, &tableformat);
+                         &numrows, &tableformat, "NONE");
 
   /* Parse the column information to set the necessary columns. */
   if( query_output_meta_col(&cols, allcols, numcols, "table_name") == 0 )
@@ -97,7 +97,8 @@ query_output_meta_database(struct queryparams *p)
   gal_list_str_reverse(&cols);
   table=gal_table_read(p->downloadname, "1", NULL, cols,
                        GAL_TABLE_SEARCH_NAME, 1, p->cp.numthreads,
-                       p->cp.minmapsize, p->cp.quietmmap, NULL);
+                       p->cp.minmapsize, p->cp.quietmmap, NULL,
+                       "NONE");
 
   /* Set the basic columns for easy reading. */
   name=table->array;
@@ -147,20 +148,27 @@ query_output_meta_database(struct queryparams *p)
 
 
 
+/* Note that these types in TAP are not case-sensitive. */
 static uint8_t
 query_type_from_tap(char *typestr)
 {
   uint8_t type;
-  if(      !strcmp(typestr,"BOOLEAN")  ) type=GAL_TYPE_UINT8;
-  else if( !strcmp(typestr,"BIGINT")   ) type=GAL_TYPE_INT64;
-  else if( !strcmp(typestr,"REAL")     ) type=GAL_TYPE_FLOAT32;
-  else if( !strcmp(typestr,"DOUBLE")   ) type=GAL_TYPE_FLOAT64;
-  else if( !strcmp(typestr,"SMALLINT")
-           || !strcmp(typestr,"INTEGER") ) type=GAL_TYPE_INT32;
-  else if( !strcmp(typestr,"VARCHAR")
-           || !strcmp(typestr,"STRING")
-           || !strncmp(typestr, "CHAR", 4) ) type=GAL_TYPE_STRING;
-  else type=GAL_TYPE_INVALID;
+  if(      !strcasecmp(typestr,"BOOLEAN")  ) type=GAL_TYPE_INT8;
+  else if( !strcasecmp(typestr,"BIGINT")
+           || !strcasecmp(typestr,"LONG") )  type=GAL_TYPE_INT64;
+  else if( !strcasecmp(typestr,"REAL")
+           || !strcasecmp(typestr,"FLOAT") ) type=GAL_TYPE_FLOAT32;
+  else if( !strcasecmp(typestr,"DOUBLE")   ) type=GAL_TYPE_FLOAT64;
+  else if( !strcasecmp(typestr,"SMALLINT")
+           || !strcasecmp(typestr,"SHORT")
+           || !strcasecmp(typestr,"INTEGER") ) type=GAL_TYPE_INT32;
+  else if( !strcasecmp(typestr,"VARCHAR")
+           || !strcasecmp(typestr,"STRING")
+           || !strncasecmp(typestr, "CHAR", 4) ) type=GAL_TYPE_STRING;
+  else
+    error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at '%s' to fix "
+          "the problem. The string '%s' is not a recognized type for "
+          "this function", __func__, PACKAGE_BUGREPORT, typestr);
   return type;
 }
 
@@ -182,7 +190,7 @@ query_output_meta_dataset(struct queryparams *p)
   /* Get the downloaded metadata column information so we can ask for the
      proper columns. */
   allcols=gal_table_info(p->downloadname, "1", NULL, &numcols,
-                         &numrows, &tableformat);
+                         &numrows, &tableformat, "NONE");
 
   /* Parse the column information to set the necessary columns. */
   if( query_output_meta_col(&cols, allcols, numcols, "column_name") == 0 )
@@ -203,7 +211,8 @@ query_output_meta_dataset(struct queryparams *p)
   gal_list_str_reverse(&cols);
   table=gal_table_read(p->downloadname, "1", NULL, cols,
                        GAL_TABLE_SEARCH_NAME, 1, p->cp.numthreads,
-                       p->cp.minmapsize, p->cp.quietmmap, NULL);
+                       p->cp.minmapsize, p->cp.quietmmap, NULL,
+                       "NONE");
 
   /* It may happen that the required dataset name isn't recognized by the
      database. In this case, 'table' will have 0 rows. */
@@ -221,6 +230,7 @@ query_output_meta_dataset(struct queryparams *p)
       allcols=gal_data_array_calloc(numcols);
       for(i=0;i<numcols;++i)
         {
+          allcols[i].minmapsize=1; /* The "repeat" for vectors. */
           allcols[i].type=query_type_from_tap(type[i]);
           gal_checkset_allocate_copy(name[i], &allcols[i].name);
           gal_checkset_allocate_copy(desc[i], &allcols[i].comment);
@@ -230,7 +240,7 @@ query_output_meta_dataset(struct queryparams *p)
 
       /* Print the basic information. */
       printf("\n--------\ndatabase: %s (URL: %s)\ndataset: %s\n",
-             p->databasestr, p->urls->v, p->datasetstr);
+             p->databasestr, p->urls->v, p->datasetuse);
       gal_table_print_info(allcols, numcols, GAL_BLANK_SIZE_T);
     }
   else
@@ -245,7 +255,7 @@ query_output_meta_dataset(struct queryparams *p)
             "command below (put any search word or phrase in 'SEARCH' to "
             "find your dataset more easily):\n\n"
             "   astquery %s --information --limitinfo=\"SEARCH\"\n\n",
-            p->datasetstr, p->databasestr, p->databasestr);
+            p->datasetuse, p->databasestr, p->databasestr);
     }
 
   /* Clean up and return. */
@@ -268,7 +278,8 @@ query_output_data(struct queryparams *p)
      downloaded table is compressed in any special FITS way). */
   table=gal_table_read(p->downloadname, "1", NULL, NULL,
                        GAL_TABLE_SEARCH_NAME, 1, p->cp.numthreads,
-                       p->cp.minmapsize, p->cp.quietmmap, NULL);
+                       p->cp.minmapsize, p->cp.quietmmap, NULL,
+                       "NONE");
   gal_table_write(table, NULL, NULL, p->cp.tableformat,
                   p->cp.output ? p->cp.output : p->cp.output,
                   "QUERY", 0);
@@ -292,7 +303,7 @@ query_output_finalize(struct queryparams *p)
   fitsfile *fptr;
   int gooddownload=0, status=0;
 
-  /* See if its a FITS file or a VOTable. */
+  /* See if it is a FITS file or a VOTable. */
   len=strlen(p->downloadname);
   if( !strcmp(&p->downloadname[len-4], ".xml") )
     { isxml=1; gooddownload=1; }
@@ -314,7 +325,7 @@ query_output_finalize(struct queryparams *p)
       /* Prepare the output dataset. */
       if(p->information)
         {
-          if(p->datasetstr)  query_output_meta_dataset(p);
+          if(p->datasetuse)  query_output_meta_dataset(p);
           else               query_output_meta_database(p);
         }
       else if(isxml==0)      query_output_data(p);
@@ -348,7 +359,8 @@ query_output_finalize(struct queryparams *p)
       gal_fits_key_list_fullcomment_add_end(&p->cp.okeys,
                                             p->finalcommand, 1);
       gal_fits_key_write_config(&p->cp.okeys, "Query settings",
-                                "QUERY-CONFIG", p->cp.output, "0");
+                                "QUERY-CONFIG", p->cp.output, "0",
+                                "NONE");
     }
 }
 
