@@ -5,7 +5,7 @@ Table is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016-2022 Free Software Foundation, Inc.
+Copyright (C) 2016-2023 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -76,7 +76,7 @@ struct arithmetic_token
   struct arithmetic_token *next;  /* Pointer to next token.               */
 };
 
-/*  */
+/* For arithmetic operations. */
 struct column_pack
 {
   size_t                    start; /* Starting ind. in requested columns. */
@@ -98,8 +98,11 @@ struct tableparams
   char               *wcsfile;  /* File with WCS.                       */
   char                *wcshdu;  /* HDU in file with WCS.                */
   gal_list_str_t     *columns;  /* List of given columns.               */
-  uint8_t         information;  /* ==1: only print FITS information.    */
+  uint8_t         information;  /* ==1: only print input information.   */
+  uint8_t         infonumrows;  /* ==1: only print input's num rows.    */
+  uint8_t         infonumcols;  /* ==1: only print input's num columns. */
   uint8_t     colinfoinstdout;  /* ==1: print column metadata in CL.    */
+  uint8_t            rowfirst;  /* Do row-based operations first.       */
   gal_data_t           *range;  /* Range to limit output.               */
   gal_data_t       *inpolygon;  /* Columns to check if inside polygon.  */
   gal_data_t      *outpolygon;  /* Columns to check if outside polygon. */
@@ -115,20 +118,25 @@ struct tableparams
   gal_data_t        *rowrange;  /* Output rows in row-counter range.    */
   size_t            rowrandom;  /* Number of rows to show randomly.     */
   uint8_t             envseed;  /* Use the environment for random seed. */
-  gal_list_str_t *catcolumnfile; /* Filename to concat column wise.     */
-  gal_list_str_t *catcolumnhdu;  /* HDU/extension for the catcolumn.    */
+  gal_list_str_t *catcolumnfile;/* Filename to concat column wise.      */
+  gal_list_str_t *catcolumnhdu; /* HDU/extension for the catcolumn.     */
   gal_list_str_t  *catcolumns;  /* List of columns to concatenate.      */
   uint8_t    catcolumnrawname;  /* Don't modify name of appended col.   */
+  gal_data_t      *fromvector;  /* Extract columns from a vector column.*/
+  uint8_t         keepvectfin;  /* Keep in.s --tovector & --fromvector. */
+  gal_list_str_t    *tovector;  /* Merge columns into a vector column.  */
+  uint8_t           transpose;  /* Transpose vector columns.            */
   gal_list_str_t  *catrowfile;  /* Filename to concat column wise.      */
   gal_list_str_t   *catrowhdu;  /* HDU/extension for the catcolumn.     */
   gal_data_t     *colmetadata;  /* Set column metadata.                 */
+  uint8_t             txteasy;  /* Easy/simple to ready txt output.     */
   char          *txtf32fmtstr;  /* Floating point formats (exp, flt).   */
   char          *txtf64fmtstr;  /* Floating point formats (exp, flt).   */
-  size_t      txtf32precision;  /* Precision of float32 in text.        */
-  size_t      txtf64precision;  /* Precision of float32 in text.        */
+  int         txtf32precision;  /* Precision of float32 in text.        */
+  int         txtf64precision;  /* Precision of float32 in text.        */
 
   /* Internal. */
-  struct column_pack *outcols;  /* Output column packages.              */
+  struct column_pack *colpack;  /* Output column packages.              */
   gal_data_t         *noblank;  /* Remove rows that have blank.         */
   gal_data_t           *table;  /* Linked list of output table columns. */
   struct wcsprm          *wcs;  /* WCS structure for conversion.        */
