@@ -190,7 +190,8 @@ parse_opt(int key, char *arg, struct argp_state *state)
          'arg' will be an empty string! We don't want to account for such
          cases (and give a clear error that no input has been given). */
       if(p->filename)
-        argp_error(state, "only one argument (input file) should be given");
+        argp_error(state, "only one argument (input file) should be given, "
+                   "extra argument is: '%s'", arg);
       else
         if(arg[0]!='\0') p->filename=arg;
       break;
@@ -606,46 +607,54 @@ ui_colpack_free(struct column_pack *list)
 /**************************************************************/
 /***************       Preparations         *******************/
 /**************************************************************/
+  /* Read the table metadata to print information. */
+static gal_data_t *
+ui_info_read(struct tableparams *p, size_t *numcols, size_t *numrows,
+             int *tableformat)
+{
+  gal_data_t *allcols;
+  gal_list_str_t *lines;
+  lines=gal_options_check_stdin(p->filename, p->cp.stdintimeout, "input");
+  allcols=gal_table_info(p->filename, p->cp.hdu, lines, numcols,
+                         numrows, tableformat, "--hdu");
+  if(p->filename==NULL) p->filename="Standard-input";
+  gal_list_str_free(lines, 1);
+  return allcols;
+}
+
+
+
+
+
+/* Print full column and row information. */
 static void
 ui_print_info_exit(struct tableparams *p)
 {
   char *tmp;
   int tableformat;
   gal_data_t *allcols;
-  gal_list_str_t *lines;
   size_t numcols, numrows;
 
-  /* Read the table information for the number of columns and rows. */
-  lines=gal_options_check_stdin(p->filename, p->cp.stdintimeout, "input");
-  allcols=gal_table_info(p->filename, p->cp.hdu, lines, &numcols,
-                         &numrows, &tableformat);
-  if(p->filename==NULL) p->filename="Standard-input";
-  gal_list_str_free(lines, 1);
-
+  /* Read the input. */
+  allcols=ui_info_read(p, &numcols, &numrows, &tableformat);
 
   /* If there was no actual data in the file, then inform the user */
   if(allcols==NULL)
     error(EXIT_FAILURE, 0, "%s: no usable data rows", p->filename);
 
-
   /* Print the file information. */
   printf("--------\n");
   tmp=gal_fits_name_save_as_string(p->filename, p->cp.hdu);
   printf("%s\n", tmp);
   free(tmp);
 
-
   /* Print each column's information. */
   gal_table_print_info(allcols, numcols, numrows);
 
-
   /* Free the information from all the columns. */
   gal_data_array_free(allcols, numcols, 0);
 
-
-  /* Free the allocated spaces and exit. Otherwise, add the number of
-     columns to the list if the user wanted to print the columns
-     (didn't just want their information. */
+  /* Free the allocated spaces and exit. */
   ui_free_report(p);
   exit(EXIT_SUCCESS);
 }
@@ -654,6 +663,69 @@ ui_print_info_exit(struct tableparams *p)
 
 
 
+/* Print number of rows or columns */
+static void
+ui_print_info_nums_exit(struct tableparams *p)
+{
+  int tableformat;
+  gal_data_t *allcols;
+  size_t numcols, numrows;
+
+  /* Read the input metadata and free the column information (which is not
+     needed here: we just want the numbers). */
+  allcols=ui_info_read(p, &numcols, &numrows, &tableformat);
+  gal_data_array_free(allcols, numcols, 0);
+
+  /* Print the respective information. */
+  if(p->infonumcols) printf("%zu\n", numcols);
+  else if(p->infonumrows) printf("%zu\n", numrows);
+  else
+    error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at '%s' to fix "
+          "the problem. This function should only be activated when "
+          "'--info-num-cols' or '--info-num-rows' are called", __func__,
+          PACKAGE_BUGREPORT);
+
+  /* Free the allocated spaces and exit. */
+  ui_free_report(p);
+  exit(EXIT_SUCCESS);
+}
+
+
+
+
+
+static void
+ui_columns_prepare_arith(struct tableparams *p, gal_data_t *colinfo,
+                         gal_list_str_t **colstoread, size_t *totcalled,
+                         size_t numcols, char *str)
+{
+  struct column_pack *node;
+
+  /* If this is the first arithmetic operation and the user has
+     already asked for some columns, we'll need to put all
+     previously requested simply-printed columns into an 'colpack'
+     structure, then add this arithmetic operation's 'colpack'. */
+  if(p->colpack==NULL && *colstoread)
+    {
+      /* Allocate an empty structure and set the necessary
+         pointers. */
+      node=ui_colpack_add_new_to_end(&p->colpack);
+      node->start=0;
+      node->numsimple=gal_list_str_number(*colstoread);
+      *totcalled=node->numsimple;
+    }
+
+  /* Add a new column pack for this arithmetic operation, then read
+     all the tokens (while specifying which columns it needs). */
+  node=ui_colpack_add_new_to_end(&p->colpack);
+  arithmetic_init(p, &node->arith, colstoread, totcalled,
+                  str+ARITHMETIC_CALL_LENGTH, colinfo, numcols);
+}
+
+
+
+
+
 /* The columns can be given as comma-separated values to one option or
    multiple calls to the column option. Here, we'll check if the input list
    has comma-separated values. If they do then the list will be updated to
@@ -661,12 +733,13 @@ ui_print_info_exit(struct tableparams *p)
 static void
 ui_columns_prepare(struct tableparams *p, gal_list_str_t *lines)
 {
-  int tableformat;
+  char *tstr;
   gal_data_t *colinfo=NULL;
+  int tableformat, arithallind=0;
   struct column_pack *node, *last;
   gal_list_str_t *tmp, *colstoread=NULL;
   size_t i, totcalled=0, numcols, numrows, numsimple;
-  char *str, countstr[11]; /* an un-signed 32-bit integer takes 10 chars */
+  char *c, *str, countstr[11]; /* an un-signed 32-bit integer takes 10 chars */
 
   /* Go over the list of requested columns from the main input. */
   for(tmp=p->columns;tmp!=NULL;tmp=tmp->next)
@@ -685,27 +758,47 @@ ui_columns_prepare(struct tableparams *p, gal_list_str_t *lines)
              information. */
           if(colinfo==NULL)
             colinfo=gal_table_info(p->filename, p->cp.hdu, lines,
-                                   &numcols, &numrows, &tableformat);
+                                   &numcols, &numrows, &tableformat,
+                                   "--hdu");
 
-          /* If this is the first arithmetic operation and the user has
-             already asked for some columns, we'll need to put all
-             previously requested simply-printed columns into an 'colpack'
-             structure, then add this arithmetic operation's 'colpack'. */
-          if(p->colpack==NULL && colstoread)
+          /* Check if '$_all' is in the string. */
+          for(c=str; *c!='\0'; ++c)
+            if(strncmp(c, "$_all", 5)==0)
+              { arithallind=c-str; break; }
+
+          /* When '$_all' is in the string, we need to repeat this option
+             for every column. Otherwise, just add this option once.*/
+          if(arithallind)
             {
-              /* Allocate an empty structure and set the necessary
-                 pointers. */
-              node=ui_colpack_add_new_to_end(&p->colpack);
-              node->start=0;
-              node->numsimple=gal_list_str_number(colstoread);
-              totcalled=node->numsimple;
-            }
+              /* Because we want to use the same bytes as '$_all' in the
+                 input string, we have four characters to write over '_all'
+                 with the number of each column. However, 'sprintf' already
+                 puts a '\0' on the last character (which we later replace
+                 with a ' '), so we only have three characters to use for
+                 column numbers. Therefore, to use this feature the input
+                 table can have a maximum of 999 columns (the FITS standard
+                 only accepts 999 columns; so it is very rare for people to
+                 need more! but we can add it if necessary). */
+              if(numcols>999)
+                error(EXIT_FAILURE, 0, "the '$_all' feature is currently "
+                      "only implemented for tables with fewer than 999 "
+                      "columns. Please contact us at %s to add more columns",
+                      PACKAGE_BUGREPORT);
 
-          /* Add a new column pack for this arithmetic operation, then read
-             all the tokens (while specifying which columns it needs). */
-          node=ui_colpack_add_new_to_end(&p->colpack);
-          arithmetic_init(p, &node->arith, &colstoread, &totcalled,
-                          str+ARITHMETIC_CALL_LENGTH, colinfo, numcols);
+              /* Repeat the arithmetic command for each column. */
+              for(i=1;i<=numcols;++i)
+                {
+                  gal_checkset_allocate_copy(str, &tstr);
+                  sprintf(tstr+arithallind+1, "%-3zu", i);
+                  tstr[arithallind+4]=' ';
+                  ui_columns_prepare_arith(p, colinfo, &colstoread, &totcalled,
+                                           numcols, tstr);
+                  free(tstr);
+                }
+            }
+          else
+            ui_columns_prepare_arith(p, colinfo, &colstoread, &totcalled,
+                                     numcols, str);
         }
 
       /* This is a simple column (no change in values). */
@@ -719,7 +812,7 @@ ui_columns_prepare(struct tableparams *p, gal_list_str_t *lines)
               if(colinfo==NULL)
                 colinfo=gal_table_info(p->filename, p->cp.hdu, lines,
                                        &numcols, &numrows,
-                                       &tableformat);
+                                       &tableformat, "--hdu");
 
               /* Add all the input column counters to the list of columns
                  to read */
@@ -934,7 +1027,7 @@ ui_check_select_sort_before(struct tableparams *p, gal_list_str_t *lines,
 
   /* Get all the input table's column information. */
   allcols=gal_table_info(p->filename, p->cp.hdu, lines, &numcols,
-                         &numrows, &tableformat);
+                         &numrows, &tableformat, "--hdu");
 
 
   /* If '--noblank' is given an '_all', we should replace it with the
@@ -1237,8 +1330,8 @@ ui_preparations(struct tableparams *p)
 
   /* If there were no columns specified or the user has asked for
      information on the columns, we want the full set of columns. */
-  if(p->information)
-    ui_print_info_exit(p);
+  if(p->information)                   ui_print_info_exit(p);
+  if(p->infonumcols || p->infonumrows) ui_print_info_nums_exit(p);
 
 
   /* If the input is from stdin, save it as 'lines'. */
@@ -1274,7 +1367,8 @@ ui_preparations(struct tableparams *p)
   /* Read the necessary columns. */
   p->table=gal_table_read(p->filename, cp->hdu, lines, p->columns,
                           cp->searchin, cp->ignorecase, cp->numthreads,
-                          cp->minmapsize, p->cp.quietmmap, p->colmatch);
+                          cp->minmapsize, p->cp.quietmmap, p->colmatch,
+                          "--hdu");
   if(p->filename==NULL) p->filename="stdin";
   gal_list_str_free(lines, 1);
 
