@@ -1,19 +1,19 @@
 /* Hierarchical argument parsing, layered over getopt
-   Copyright (C) 1995-2017 Free Software Foundation, Inc.
+   Copyright (C) 1995-2023 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Written by Miles Bader <miles@gnu.ai.mit.edu>.
 
-   This program is free software: you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
-   (at your option) any later version.
+   This file is free software: you can redistribute it and/or modify
+   it under the terms of the GNU Lesser General Public License as
+   published by the Free Software Foundation, either version 3 of the
+   License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This file is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU Lesser General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
+   You should have received a copy of the GNU Lesser General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #ifdef HAVE_CONFIG_H
@@ -21,7 +21,6 @@
 #endif
 
 #include <alloca.h>
-#include <stdalign.h>
 #include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
@@ -249,7 +248,7 @@ struct parser
   /* LONG_OPTS is the array of getop long option structures for the union of
      all the groups of options.  */
   struct option *long_opts;
-  /* OPT_DATA is the getopt data used for the re-entrant getopt.  */
+  /* OPT_DATA is the getopt data used for the reentrant getopt.  */
   struct _getopt_data opt_data;
 
   /* States of the various parsing groups.  */
@@ -356,9 +355,9 @@ convert_options (const struct argp *argp,
       group->args_processed = 0;
       group->parent = parent;
       group->parent_index = parent_index;
-      group->input = 0;
-      group->hook = 0;
-      group->child_inputs = 0;
+      group->input = NULL;
+      group->hook = NULL;
+      group->child_inputs = NULL;
 
       if (children)
         /* Assign GROUP's CHILD_INPUTS field some space from
@@ -374,7 +373,7 @@ convert_options (const struct argp *argp,
       parent = group++;
     }
   else
-    parent = 0;
+    parent = NULL;
 
   if (children)
     {
@@ -913,7 +912,7 @@ __argp_parse (const struct argp *argp, int argc, char **argv, unsigned flags,
       (child++)->argp = &argp_default_argp;
       if (argp_program_version || argp_program_version_hook)
         (child++)->argp = &argp_version_argp;
-      child->argp = 0;
+      child->argp = NULL;
 
       argp = top_argp;
     }
@@ -950,7 +949,7 @@ __argp_input (const struct argp *argp, const struct argp_state *state)
           return group->input;
     }
 
-  return 0;
+  return NULL;
 }
 #ifdef weak_alias
 weak_alias (__argp_input, _argp_input)
