@@ -1,10 +1,10 @@
 /* Searching a string for a character among a given set of characters.
-   Copyright (C) 1999, 2002, 2006-2021 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2002, 2006-2023 Free Software Foundation, Inc.
    Written by Bruno Haible <bruno@clisp.org>, 2007.
 
    This file is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as
-   published by the Free Software Foundation; either version 3 of the
+   published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.
 
    This file is distributed in the hope that it will be useful,
@@ -20,7 +20,13 @@
 /* Specification.  */
 #include <string.h>
 
-#include "mbuiter.h"
+#include <stdlib.h>
+
+#if GNULIB_MCEL_PREFER
+# include "mcel.h"
+#else
+# include "mbuiterf.h"
+#endif
 
 /* Find the first occurrence in the character string STRING of any character
    in the character string ACCEPT.  Return the pointer to it, or NULL if none
@@ -36,26 +42,51 @@ mbspbrk (const char *string, const char *accept)
   /* General case.  */
   if (MB_CUR_MAX > 1)
     {
-      mbui_iterator_t iter;
-
-      for (mbui_init (iter, string); mbui_avail (iter); mbui_advance (iter))
+      char const *iter = string;
+#if GNULIB_MCEL_PREFER
+      mcel_t a, g;
+      for (; *iter; iter += g.len)
         {
-          if (mb_len (mbui_cur (iter)) == 1)
+          g = mcel_scanz (iter);
+          if (g.len == 1)
             {
-              if (mbschr (accept, * mbui_cur_ptr (iter)))
-                return (char *) mbui_cur_ptr (iter);
+              if (mbschr (accept, *iter))
+                return (char *) iter;
+            }
+          else
+            for (char const *aiter = accept; *aiter; aiter += a.len)
+              {
+                a = mcel_scanz (aiter);
+                if (mcel_cmp (a, g) == 0)
+                  return (char *) iter;
+              }
+        }
+#else
+      mbuif_state_t state;
+      for (mbuif_init (state); mbuif_avail (state, iter); )
+        {
+          mbchar_t cur = mbuif_next (state, iter);
+          if (mb_len (cur) == 1)
+            {
+              if (mbschr (accept, *iter))
+                return (char *) iter;
             }
           else
             {
-              mbui_iterator_t aiter;
-
-              for (mbui_init (aiter, accept);
-                   mbui_avail (aiter);
-                   mbui_advance (aiter))
-                if (mb_equal (mbui_cur (aiter), mbui_cur (iter)))
-                  return (char *) mbui_cur_ptr (iter);
+              mbuif_state_t astate;
+              const char *aiter;
+              for (mbuif_init (astate), aiter = accept;
+                   mbuif_avail (astate, aiter); )
+                {
+                  mbchar_t acur = mbuif_next (astate, aiter);
+                  if (mb_equal (acur, cur))
+                    return (char *) iter;
+                  aiter += mb_len (acur);
+                }
             }
+          iter += mb_len (cur);
         }
+#endif
       return NULL;
     }
   else
