@@ -118,6 +118,7 @@ enum options_common_keys
   GAL_OPTIONS_KEY_SEARCHIN,
   GAL_OPTIONS_KEY_LASTCONFIG,
   GAL_OPTIONS_KEY_CHECKCONFIG,
+  GAL_OPTIONS_KEY_CONFIGPREFIX,
   GAL_OPTIONS_KEY_TABLEFORMAT,
   GAL_OPTIONS_KEY_ONLYVERSION,
   GAL_OPTIONS_KEY_WORKOVERCH,
@@ -215,6 +216,7 @@ struct gal_options_common_params
   uint8_t           setusrconf; /* To write teh user config config file.  */
   uint8_t           lastconfig; /* This is the last configuration file.   */
   uint8_t          checkconfig; /* Check config files and values.         */
+  char           *configprefix; /* Custom prefix in --config files.       */
 
   /* Output files. */
   gal_fits_list_key_t  *okeys;  /* Configuration as FITS keys in output.  */
