@@ -5,7 +5,8 @@ This is part of GNU Astronomy Utilities (Gnuastro) package.
 Original author:
      Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2017-2022 Free Software Foundation, Inc.
+     Faezeh Bidjarchian <fbidjarchian@gmail.com>
+Copyright (C) 2017-2023 Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -24,7 +25,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #define __GAL_ARITHMETIC_H__
 
 /* Include other headers if necessary here. Note that other header files
-   must be included before the C++ preparations below */
+   must be included before the C++ preparations below. */
 #include <gnuastro/data.h>
 
 
@@ -35,7 +36,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
    programs, this information is kept in 'gnuastro/config.h'. Note that all
    '.c' files must start with the inclusion of 'config.h' and that
    'gnuastro/config.h' is only created at installation time (not present
-   during the building of Gnuastro).*/
+   during the building of Gnuastro). */
 #ifndef IN_GNUASTRO_BUILD
 #include <gnuastro/config.h>
 #endif
@@ -102,6 +103,7 @@ enum gal_arithmetic_operators
   GAL_ARITHMETIC_OP_OR,           /*   ||    */
   GAL_ARITHMETIC_OP_NOT,          /*   !     */
   GAL_ARITHMETIC_OP_ISBLANK,      /* Similar to isnan() for floats. */
+  GAL_ARITHMETIC_OP_ISNOTBLANK,   /* Inverse of 'isblank'. */
   GAL_ARITHMETIC_OP_WHERE,        /*   ?:    */
 
   GAL_ARITHMETIC_OP_BITAND,       /*   &     */
@@ -133,7 +135,6 @@ enum gal_arithmetic_operators
 
   GAL_ARITHMETIC_OP_E,            /* The base of natural logirithm. */
   GAL_ARITHMETIC_OP_PI,           /* Circle circumference by diameter. */
-
   GAL_ARITHMETIC_OP_C,            /* The speed of light. */
   GAL_ARITHMETIC_OP_G,            /* The gravitational constant. */
   GAL_ARITHMETIC_OP_H,            /* Plank's constant. */
@@ -152,10 +153,12 @@ enum gal_arithmetic_operators
   GAL_ARITHMETIC_OP_SB_TO_MAG,    /* Surface Brightness to Magnitude. */
   GAL_ARITHMETIC_OP_COUNTS_TO_SB, /* Counts to Surface Brightness. */
   GAL_ARITHMETIC_OP_SB_TO_COUNTS, /* Surface Brightness to counts. */
-  GAL_ARITHMETIC_OP_COUNTS_TO_JY, /* Counts to Janskys with AB-mag zeropoint. */
-  GAL_ARITHMETIC_OP_JY_TO_COUNTS, /* Janskys to Counts with AB-mag zeropoint. */
+  GAL_ARITHMETIC_OP_COUNTS_TO_JY, /* Counts to Janskys (AB zeropoint). */
+  GAL_ARITHMETIC_OP_JY_TO_COUNTS, /* Janskys to Counts (AB zeropoint). */
   GAL_ARITHMETIC_OP_MAG_TO_JY,    /* Magnitude to Janskys. */
   GAL_ARITHMETIC_OP_JY_TO_MAG,    /* Janskys to Magnitude. */
+  GAL_ARITHMETIC_OP_COUNTS_TO_NANOMAGGY,/* Counts to SDSS nanomaggies. */
+  GAL_ARITHMETIC_OP_NANOMAGGY_TO_COUNTS,/* SDSS nanomaggies to counts. */
   GAL_ARITHMETIC_OP_AU_TO_PC,     /* Astronomical units (AU) to Parsecs (PC). */
   GAL_ARITHMETIC_OP_PC_TO_AU,     /* Parsecs (PC) to Astronomical units (AU). */
   GAL_ARITHMETIC_OP_LY_TO_PC,     /* Astronomical units (AU) to Parsecs (PC). */
@@ -187,14 +190,15 @@ enum gal_arithmetic_operators
   GAL_ARITHMETIC_OP_SIGCLIP_STD,  /* Sigma-clipped STD of multiple arrays. */
 
   GAL_ARITHMETIC_OP_MKNOISE_SIGMA,/* Fixed-sigma noise to every element.   */
+  GAL_ARITHMETIC_OP_MKNOISE_SIGMA_FROM_MEAN, /* Sigma comes from background. */
   GAL_ARITHMETIC_OP_MKNOISE_POISSON,/* Poission noise on every element.    */
   GAL_ARITHMETIC_OP_MKNOISE_UNIFORM,/* Uniform noise on every element.     */
   GAL_ARITHMETIC_OP_RANDOM_FROM_HIST,/* Randoms from a histogram (uniform).*/
   GAL_ARITHMETIC_OP_RANDOM_FROM_HIST_RAW,/* Randoms from a histogram (raw).*/
 
-  GAL_ARITHMETIC_OP_SIZE,         /* Size of the dataset along an axis     */
-
   GAL_ARITHMETIC_OP_STITCH,       /* Stitch multiple datasets together.    */
+  GAL_ARITHMETIC_OP_TO1D,         /* Make they output into a 1D array.     */
+  GAL_ARITHMETIC_OP_TRIM,         /* Trim blank rows or columns in image.  */
 
   GAL_ARITHMETIC_OP_TO_UINT8,     /* Convert to uint8_t.                   */
   GAL_ARITHMETIC_OP_TO_INT8,      /* Convert to int8_t.                    */
@@ -208,9 +212,58 @@ enum gal_arithmetic_operators
   GAL_ARITHMETIC_OP_TO_FLOAT64,   /* Convert to float64.                   */
 
   GAL_ARITHMETIC_OP_BOX_AROUND_ELLIPSE, /* Width/Height of box over ellipse*/
+  GAL_ARITHMETIC_OP_BOX_VERTICES_ON_SPHERE, /* Vert. from center and width */
 
+  /* Meta operators */
+  GAL_ARITHMETIC_OP_SIZE,         /* Size of the dataset along an axis.    */
   GAL_ARITHMETIC_OP_MAKENEW,      /* Build a new dataset, containing zeros.*/
+  GAL_ARITHMETIC_OP_INDEX,        /* New with the index (counting from 0). */
+  GAL_ARITHMETIC_OP_COUNTER,      /* New with the index (counting from 0). */
+  GAL_ARITHMETIC_OP_INDEXONLY,    /* New with the index (counting from 0). */
+  GAL_ARITHMETIC_OP_COUNTERONLY,  /* New with the index (counting from 1). */
+  GAL_ARITHMETIC_OP_SWAP,         /* Swap the top two operands.            */
+  GAL_ARITHMETIC_OP_CONSTANT,     /* Make a row with given constant.       */
 
+  /* Pooling operators. */
+  GAL_ARITHMETIC_OP_POOLMAX,      /* The pool-max of desired pixels.       */
+  GAL_ARITHMETIC_OP_POOLMIN,      /* The pool-min of desired pixels.       */
+  GAL_ARITHMETIC_OP_POOLSUM,      /* The pool-sum of desired pixels.       */
+  GAL_ARITHMETIC_OP_POOLMEAN,     /* The pool-mean of desired pixels.      */
+  GAL_ARITHMETIC_OP_POOLMEDIAN,   /* The pool-median of desired pixels.    */
+
+  /* Celestial coordinate conversions (names are clear, no comment). */
+  GAL_ARITHMETIC_OP_EQB1950_TO_EQJ2000,
+  GAL_ARITHMETIC_OP_EQB1950_TO_ECB1950,
+  GAL_ARITHMETIC_OP_EQB1950_TO_ECJ2000,
+  GAL_ARITHMETIC_OP_EQB1950_TO_GALACTIC,
+  GAL_ARITHMETIC_OP_EQB1950_TO_SUPERGALACTIC,
+  GAL_ARITHMETIC_OP_EQJ2000_TO_EQB1950,
+  GAL_ARITHMETIC_OP_EQJ2000_TO_ECB1950,
+  GAL_ARITHMETIC_OP_EQJ2000_TO_ECJ2000,
+  GAL_ARITHMETIC_OP_EQJ2000_TO_GALACTIC,
+  GAL_ARITHMETIC_OP_EQJ2000_TO_SUPERGALACTIC,
+  GAL_ARITHMETIC_OP_ECB1950_TO_EQB1950,
+  GAL_ARITHMETIC_OP_ECB1950_TO_EQJ2000,
+  GAL_ARITHMETIC_OP_ECB1950_TO_ECJ2000,
+  GAL_ARITHMETIC_OP_ECB1950_TO_GALACTIC,
+  GAL_ARITHMETIC_OP_ECB1950_TO_SUPERGALACTIC,
+  GAL_ARITHMETIC_OP_ECJ2000_TO_EQB1950,
+  GAL_ARITHMETIC_OP_ECJ2000_TO_EQJ2000,
+  GAL_ARITHMETIC_OP_ECJ2000_TO_ECB1950,
+  GAL_ARITHMETIC_OP_ECJ2000_TO_GALACTIC,
+  GAL_ARITHMETIC_OP_ECJ2000_TO_SUPERGALACTIC,
+  GAL_ARITHMETIC_OP_GALACTIC_TO_EQB1950,
+  GAL_ARITHMETIC_OP_GALACTIC_TO_EQJ2000,
+  GAL_ARITHMETIC_OP_GALACTIC_TO_ECB1950,
+  GAL_ARITHMETIC_OP_GALACTIC_TO_ECJ2000,
+  GAL_ARITHMETIC_OP_GALACTIC_TO_SUPERGALACTIC,
+  GAL_ARITHMETIC_OP_SUPERGALACTIC_TO_EQB1950,
+  GAL_ARITHMETIC_OP_SUPERGALACTIC_TO_EQJ2000,
+  GAL_ARITHMETIC_OP_SUPERGALACTIC_TO_ECB1950,
+  GAL_ARITHMETIC_OP_SUPERGALACTIC_TO_ECJ2000,
+  GAL_ARITHMETIC_OP_SUPERGALACTIC_TO_GALACTIC,
+
+  /* Counter for number of operators. */
   GAL_ARITHMETIC_OP_LAST_CODE,    /* Last code of the library operands.    */
 };
 
